@@ -1,9 +1,10 @@
 from ..multi_tube_source import MultiTubeSource
-from ..utils import MoveWithSpeed
+from ..utils import MoveWithSpeed, mix_bottom_top
 from .p1000 import StationAP1000
 from .reload import StationAReloadMixin
 from .copan_24 import Copan24Specs
 from .copan_48 import copan_48_corrected_specs
+from .copan_48_saliva import copan_48_saliva_corrected_specs
 from typing import Tuple, Optional
 
 
@@ -15,8 +16,9 @@ class StationATechnogenetics(StationAP1000):
         beads_vol: float = 9,
         drop_threshold: int = 5000,
         deepwell_headroom_bottom: float = 2,
-        lys_mix_repeats: int = 2,
+        lys_mix_repeats: int = 0,
         lys_mix_volume: float = 400,
+        lys_mix_last_rate: float = 100,
         lysis_volume: float = 400,
         lysis_in_controls: bool = True,
         lysis_rate_aspirate: float = 600,
@@ -63,6 +65,7 @@ class StationATechnogenetics(StationAP1000):
             lysis_first=True,       # This not an option for this protocol
             lys_mix_repeats=lys_mix_repeats,
             lys_mix_volume=lys_mix_volume,
+            lys_mix_last_rate=lys_mix_last_rate,
             lysis_volume=lysis_volume,
             lysis_in_controls=lysis_in_controls,
             lysis_rate_aspirate=lysis_rate_aspirate,
@@ -245,9 +248,6 @@ class StationATechnogenetics(StationAP1000):
         self.setup_lys_tube()
         self.msg = ""
 
-        if self.run_stage("add beads"):
-            self.pause("add beads", home=False)
-
         self.transfer_lys()
         self.transfer_beads(new_tip=False)
         self.transfer_proteinase()
@@ -298,6 +298,76 @@ class StationATechnogenetics48(StationATechnogeneticsReload):
             ) for i, slot in enumerate(self._source_racks_slots)
         ]
 
+
+class StationATechnogenetics48Saliva(StationATechnogenetics48):
+    def __init__(
+            self,
+            air_gap_sample_before=200,
+            deepwell_vertical_speed=25,
+            deepwell_after_dispense_touch_border=True,
+            drop_height=-30,
+            lys_mix_repeats: int = 4,
+            lys_mix_volume=500,
+            lysis_mix_rate=800,
+            lys_mix_last_rate=100,
+            lys_mix_last_volume=200,
+            sample_lateral_air_gap=25,
+            sample_lateral_top_height=3,
+            sample_lateral_x_move=-10,
+            sample_lateral_y_move=0,
+            source_headroom_height=1,
+            *args,
+            **kwargs
+    ):
+        super(StationATechnogenetics48Saliva, self).__init__(
+            air_gap_sample_before=air_gap_sample_before,
+            deepwell_vertical_speed=deepwell_vertical_speed,
+            deepwell_after_dispense_touch_border=deepwell_after_dispense_touch_border,
+            drop_height=drop_height,
+            lys_mix_repeats=lys_mix_repeats,
+            lys_mix_volume=lys_mix_volume,
+            lysis_rate_mix=lysis_mix_rate,
+            lys_mix_last_rate=lys_mix_last_rate,
+            lys_mix_last_volume=lys_mix_last_volume,
+            sample_lateral_air_gap=sample_lateral_air_gap,
+            sample_lateral_top_height=sample_lateral_top_height,
+            sample_lateral_x_move=sample_lateral_x_move,
+            sample_lateral_y_move=sample_lateral_y_move,
+            source_headroom_height=source_headroom_height,
+            *args,
+            **kwargs
+        )
+
+    def _load_source_racks(self):
+        labware_def = copan_48_saliva_corrected_specs.labware_definition()
+        self._source_racks = [
+            self._ctx.load_labware_from_definition(
+                labware_def, slot,
+                'source tuberack ' + str(i + 1)
+            ) for i, slot in enumerate(self._source_racks_slots)
+        ]
+
+    def transfer_sample_mix(self, well, height1: float, height2: float):
+        """ Just another mixing function to have a clean tip before ejecting """
+        if self._lys_mix_repeats:
+            for i in range(self._lys_mix_repeats):
+                if self._lys_mix_repeats > 1:
+                    vol_to_mix = round((self._lys_mix_volume - self._lys_mix_last_volume) * (1 - (i/(self._lys_mix_repeats-1)))
+                                       + self._lys_mix_last_volume)
+                else:
+                    vol_to_mix = self._lys_mix_volume
+
+                self.logger.info("Decremental mix with volume: {}".format(vol_to_mix))
+                mix_bottom_top(
+                    pip=self._p_main,
+                    reps=1,
+                    vol=vol_to_mix,
+                    pos=well.bottom,
+                    bottom=height1,
+                    top=height2,
+                    last_dispense_rate=self._lys_mix_last_rate if i == (self._lys_mix_repeats-1) else None
+                )
+
 if __name__ == "__main__":
     StationATechnogenetics48(num_samples=96, metadata={'apiLevel': '2.7'}).simulate()
 
